@@ -1,17 +1,17 @@
 use crate::{
-    command::{sample_encode, PROGRESS_CHARS},
+    command::{args, sample_encode, PROGRESS_CHARS},
     console_ext::style,
 };
 use anyhow::{bail, ensure};
 use clap::Parser;
 use console::style;
 use indicatif::{HumanBytes, HumanDuration, ProgressBar, ProgressStyle};
-use std::{path::PathBuf, time::Duration};
+use std::time::Duration;
 
 const BAR_LEN: u64 = 1000;
 
-/// Interpolated binary search using sample-encode to find the best crf value
-/// delivering min-vmaf & max-encoded-percent.
+/// Interpolated binary search using sample-encode to find the best crf
+/// value delivering min-vmaf & max-encoded-percent.
 ///
 /// Outputs:
 /// * Best crf value
@@ -21,13 +21,8 @@ const BAR_LEN: u64 = 1000;
 #[derive(Parser)]
 #[clap(verbatim_doc_comment)]
 pub struct Args {
-    /// Input video file.
-    #[clap(short, long)]
-    pub input: PathBuf,
-
-    /// Encoder preset. Higher presets means faster encodes, but with a quality tradeoff.
-    #[clap(long)]
-    pub preset: u8,
+    #[clap(flatten)]
+    pub svt: args::SvtEncode,
 
     /// Desired min VMAF score to deliver.
     #[clap(long, default_value_t = 95.0)]
@@ -45,13 +40,14 @@ pub struct Args {
     #[clap(long, default_value_t = 55)]
     pub max_crf: u8,
 
-    /// Number of 20s samples to use across the input video.
-    /// More samples take longer but may provide a more accurate result.
-    #[clap(long, default_value_t = 3)]
-    pub samples: u64,
+    #[clap(flatten)]
+    pub sample: args::Sample,
 
     #[clap(skip)]
     pub quiet: bool,
+
+    #[clap(flatten)]
+    pub vmaf: args::Vmaf,
 }
 
 pub async fn crf_search(args: Args) -> anyhow::Result<()> {
@@ -60,24 +56,15 @@ pub async fn crf_search(args: Args) -> anyhow::Result<()> {
             .template("{spinner:.cyan.bold} {elapsed_precise:.bold} {wide_bar:.cyan/blue} ({msg}eta {eta})")
             .progress_chars(PROGRESS_CHARS)
     );
-    // bar.enable_steady_tick(100);
 
     let best = run(&args, bar.clone()).await?;
-
     bar.finish();
 
     // encode how-to hint + predictions
     eprintln!(
         "\n{} {}\n",
         style("Encode with:").dim(),
-        style!(
-            "ab-av1 encode -i {:?} --crf {} --preset {}",
-            args.input,
-            best.crf,
-            args.preset,
-        )
-        .dim()
-        .italic()
+        style(args.svt.encode_hint(best.crf)).dim().italic(),
     );
 
     StdoutFormat::Human.print_result(&best);
@@ -87,26 +74,26 @@ pub async fn crf_search(args: Args) -> anyhow::Result<()> {
 
 pub async fn run(
     Args {
-        input,
-        preset,
+        svt,
         min_vmaf,
         max_encoded_percent,
         min_crf,
         max_crf,
-        samples,
+        sample,
         quiet,
+        vmaf,
     }: &Args,
     bar: ProgressBar,
 ) -> anyhow::Result<Sample> {
     ensure!(min_crf <= max_crf, "Invalid --min-crf & --max-crf");
 
     let mut args = sample_encode::Args {
-        input: input.clone(),
+        svt: svt.clone(),
         crf: (min_crf + max_crf) / 2,
-        preset: *preset,
-        samples: *samples,
+        sample: sample.clone(),
         keep: false,
         stdout_format: sample_encode::StdoutFormat::Json,
+        vmaf: vmaf.clone(),
     };
 
     bar.set_length(BAR_LEN);
